package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicArea;
import com.bonus.canteen.core.basic.service.IBasicAreaService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 区域Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "区域接口")
@RestController
@RequestMapping("/basic_area")
public class BasicAreaController extends BaseController {
    @Autowired
    private IBasicAreaService basicAreaService;

    /**
     * 查询区域列表
     */
    @ApiOperation(value = "查询区域列表")
    //@RequiresPermissions("basic:area:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicArea basicArea) {
        startPage();
        List<BasicArea> list = basicAreaService.selectBasicAreaList(basicArea);
        return getDataTable(list);
    }

    @GetMapping("/areaTree")
    public AjaxResult deptTree(BasicArea area) {
        try {
            return success(basicAreaService.selectAreaTreeList(area));
        } catch (Exception e) {
            logger.error(e.toString(), e);
        }
        return error("系统异常,请联系管理员");
    }

    /**
     * 导出区域列表
     */
    @ApiOperation(value = "导出区域列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:area:export")
    @SysLog(title = "区域", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出区域")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicArea basicArea) {
        List<BasicArea> list = basicAreaService.selectBasicAreaList(basicArea);
        ExcelUtil<BasicArea> util = new ExcelUtil<BasicArea>(BasicArea.class);
        util.exportExcel(response, list, "区域数据");
    }

    /**
     * 获取区域详细信息
     */
    @ApiOperation(value = "获取区域详细信息")
    //@RequiresPermissions("basic:area:query")
    @GetMapping(value = "/{areaId}")
    public AjaxResult getInfo(@PathVariable("areaId") Long areaId) {
        return success(basicAreaService.selectBasicAreaByAreaId(areaId));
    }

    /**
     * 新增区域
     */
    @ApiOperation(value = "新增区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:area:add")
    @SysLog(title = "区域", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增区域")
    @PostMapping
    public AjaxResult add(@RequestBody BasicArea basicArea) {
        try {
            return toAjax(basicAreaService.insertBasicArea(basicArea));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改区域
     */
    @ApiOperation(value = "修改区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:area:edit")
    @SysLog(title = "区域", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改区域")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicArea basicArea) {
        try {
            return toAjax(basicAreaService.updateBasicArea(basicArea));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除区域
     */
    @ApiOperation(value = "删除区域")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:area:remove")
    @SysLog(title = "区域", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除区域")
	@PostMapping("/del/{areaIds}")
    public AjaxResult remove(@PathVariable Long[] areaIds) {
        return toAjax(basicAreaService.deleteBasicAreaByAreaIds(areaIds));
    }
}
